
.. include:: ../README.rst

Bugs
-----
``hfinder`` is of course entirely bug free! However, if you do find an issue,
please raise it at the `github page`_.

.. _github page: https://github.com/HiPERCAM/uspec_finder/issues

Usage
-----

Please see the :doc:`detailed usage instructions <usage>`

.. toctree::
    :maxdepth: 2

    usage
    hipercam

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
